HeraldEvent class

A wrapper for globally-captured Herald events.

Used by Herald.allEvents to provide both the event type and payload in a single object.

Constructors

HeraldEvent(Type type, dynamic payload)
Creates a HeraldEvent.

Properties

hashCode int
The hash code for this object.
no setterinherited
payload → dynamic
The event payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When the event was emitted.
final
type Type
The Dart Type of the event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited