NexusRemove<T> class final

An element was removed from a list.

Inheritance

Constructors

NexusRemove(int index, T element)
const

Properties

element → T
The element that was removed.
final
hashCode int
The hash code for this object.
no setterinherited
index int
The index from which the element was removed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited