NexusUpdate<T> class final

An element was updated in a list at a specific index.

Inheritance

Constructors

NexusUpdate(int index, T oldValue, T newValue)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The index of the updated element.
final
newValue → T
The new value at this index.
final
oldValue → T
The previous value at this index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited