ConduitRejectedException class
Thrown by a Conduit.pipe to reject a state change.
When thrown, the Core's value remains unchanged and no notifications are sent. Callers can catch this to handle rejected updates.
try {
health.value = -10;
} on ConduitRejectedException catch (e) {
print('Rejected: ${e.message}');
}
- Implemented types
Constructors
- ConduitRejectedException({String? message, Object? rejectedValue})
-
Creates a rejection exception.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
A human-readable description of why the change was rejected.
final
- rejectedValue → Object?
-
The value that was rejected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited