ConsoleLogSink class
A console LogSink with formatted, colorized output.
Chronicle.addSink(ConsoleLogSink());
Constructors
- ConsoleLogSink({LogLevel minLevel = LogLevel.trace})
- Creates a ConsoleLogSink.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLevel → LogLevel
-
Minimum level to print. Defaults to LogLevel.trace (all).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
LogEntry entry) → void -
Write a log entry to this sink.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited