HeraldEvent class
A wrapper for globally-captured Herald events.
Used by Herald.allEvents to provide both the event type and payload in a single object.
Constructors
- HeraldEvent(Type type, dynamic payload)
- Creates a HeraldEvent.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited