NexusMapSet<K, V> class
final
A key-value pair was set in a map.
- Inheritance
-
- Object
- NexusChange<
MapEntry< K, V> > - NexusMapSet
Constructors
- NexusMapSet(K key, V? oldValue, V newValue, {bool isNew = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNew → bool
-
Whether this was a new key (vs. update).
final
- key → K
-
The key that was set.
final
- newValue → V
-
The new value.
final
- oldValue → V?
-
The previous value (null if new key).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited