WritViolation class
Details of a Writ that failed evaluation.
Included in MandateDenial.violations to explain why access was denied.
Constructors
- WritViolation({required String writName, String? reason})
-
Creates a writ violation record.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- reason → String?
-
Human-readable denial reason (from Writ.reason).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writName → String
-
Name of the writ that failed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override